@@ -15,18 +15,18 @@ import sys
 from typing import IO, Dict, List, Union
 
 from .literals import (
-    ApiCacheStatus,
-    ApiCacheType,
-    ApiCachingBehavior,
-    AuthenticationType,
-    ConflictDetectionType,
-    ConflictHandlerType,
-    DataSourceType,
-    DefaultAction,
-    FieldLogLevel,
-    ResolverKind,
-    SchemaStatus,
-    TypeDefinitionFormat,
+    ApiCacheStatusType,
+    ApiCacheTypeType,
+    ApiCachingBehaviorType,
+    AuthenticationTypeType,
+    ConflictDetectionTypeType,
+    ConflictHandlerTypeType,
+    DataSourceTypeType,
+    DefaultActionType,
+    FieldLogLevelType,
+    ResolverKindType,
+    SchemaStatusType,
+    TypeDefinitionFormatType,
 )
 
 if sys.version_info >= (3, 8):
@@ -102,7 +102,7 @@ __all__ = (
 AdditionalAuthenticationProviderTypeDef = TypedDict(
     "AdditionalAuthenticationProviderTypeDef",
     {
-        "authenticationType": AuthenticationType,
+        "authenticationType": AuthenticationTypeType,
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
         "userPoolConfig": "CognitoUserPoolConfigTypeDef",
     },
@@ -113,11 +113,11 @@ ApiCacheTypeDef = TypedDict(
     "ApiCacheTypeDef",
     {
         "ttl": int,
-        "apiCachingBehavior": ApiCachingBehavior,
+        "apiCachingBehavior": ApiCachingBehaviorType,
         "transitEncryptionEnabled": bool,
         "atRestEncryptionEnabled": bool,
-        "type": ApiCacheType,
-        "status": ApiCacheStatus,
+        "type": ApiCacheTypeType,
+        "status": ApiCacheStatusType,
     },
     total=False,
 )
@@ -256,7 +256,7 @@ DataSourceTypeDef = TypedDict(
         "dataSourceArn": str,
         "name": str,
         "description": str,
-        "type": DataSourceType,
+        "type": DataSourceTypeType,
         "serviceRoleArn": str,
         "dynamodbConfig": "DynamodbDataSourceConfigTypeDef",
         "lambdaConfig": "LambdaDataSourceConfigTypeDef",
@@ -376,7 +376,7 @@ GetResolverResponseTypeDef = TypedDict(
 GetSchemaCreationStatusResponseTypeDef = TypedDict(
     "GetSchemaCreationStatusResponseTypeDef",
     {
-        "status": SchemaStatus,
+        "status": SchemaStatusType,
         "details": str,
     },
     total=False,
@@ -395,7 +395,7 @@ GraphqlApiTypeDef = TypedDict(
     {
         "name": str,
         "apiId": str,
-        "authenticationType": AuthenticationType,
+        "authenticationType": AuthenticationTypeType,
         "logConfig": "LogConfigTypeDef",
         "userPoolConfig": "UserPoolConfigTypeDef",
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
@@ -507,7 +507,7 @@ ListTypesResponseTypeDef = TypedDict(
 _RequiredLogConfigTypeDef = TypedDict(
     "_RequiredLogConfigTypeDef",
     {
-        "fieldLogLevel": FieldLogLevel,
+        "fieldLogLevel": FieldLogLevelType,
         "cloudWatchLogsRoleArn": str,
     },
 )
@@ -595,7 +595,7 @@ ResolverTypeDef = TypedDict(
         "resolverArn": str,
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
-        "kind": ResolverKind,
+        "kind": ResolverKindType,
         "pipelineConfig": "PipelineConfigTypeDef",
         "syncConfig": "SyncConfigTypeDef",
         "cachingConfig": "CachingConfigTypeDef",
@@ -606,7 +606,7 @@ ResolverTypeDef = TypedDict(
 StartSchemaCreationResponseTypeDef = TypedDict(
     "StartSchemaCreationResponseTypeDef",
     {
-        "status": SchemaStatus,
+        "status": SchemaStatusType,
     },
     total=False,
 )
@@ -614,8 +614,8 @@ StartSchemaCreationResponseTypeDef = TypedDict(
 SyncConfigTypeDef = TypedDict(
     "SyncConfigTypeDef",
     {
-        "conflictHandler": ConflictHandlerType,
-        "conflictDetection": ConflictDetectionType,
+        "conflictHandler": ConflictHandlerTypeType,
+        "conflictDetection": ConflictDetectionTypeType,
         "lambdaConflictHandlerConfig": "LambdaConflictHandlerConfigTypeDef",
     },
     total=False,
@@ -628,7 +628,7 @@ TypeTypeDef = TypedDict(
         "description": str,
         "arn": str,
         "definition": str,
-        "format": TypeDefinitionFormat,
+        "format": TypeDefinitionFormatType,
     },
     total=False,
 )
@@ -694,7 +694,7 @@ _RequiredUserPoolConfigTypeDef = TypedDict(
     {
         "userPoolId": str,
         "awsRegion": str,
-        "defaultAction": DefaultAction,
+        "defaultAction": DefaultActionType,
     },
 )
 _OptionalUserPoolConfigTypeDef = TypedDict(
